/* dev_hash.h
 *
 * protos for functions that lookup device names */

char *devname PARAMS((long dev_num));
